public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] powernow-k8: On load failure, remind the user to enable support in BIOS setup
@ 2010-01-20 15:33 Marti Raudsepp
  2010-01-20 15:56 ` Thomas Renninger
  0 siblings, 1 reply; 3+ messages in thread
From: Marti Raudsepp @ 2010-01-20 15:33 UTC (permalink / raw)
  To: cpufreq
  Cc: Dave Jones, Thomas Gleixner, Ingo Molnar, H. Peter Anvin, x86,
	Thomas Renninger, Mark Langsdorf, Rusty Russell, Andreas Herrmann,
	linux-kernel

 arch/x86/kernel/cpu/cpufreq/powernow-k8.c |  15 +++++++++------
 1 files changed, 9 insertions(+), 6 deletions(-)


In most cases this is simply user error or bad BIOS defaults, rather than a
firmware problem.

Signed-off-by: Marti Raudsepp <marti@juffo.org>

diff --git a/arch/x86/kernel/cpu/cpufreq/powernow-k8.c b/arch/x86/kernel/cpu/cpufreq/powernow-k8.c
--- a/arch/x86/kernel/cpu/cpufreq/powernow-k8.c
+++ b/arch/x86/kernel/cpu/cpufreq/powernow-k8.c
@@ -789,17 +789,20 @@
 				(struct pst_s *)(psb+1), maxvid);
 	}
 	/*
 	 * If you see this message, complain to BIOS manufacturer. If
 	 * he tells you "we do not support Linux" or some similar
 	 * nonsense, remember that Windows 2000 uses the same legacy
 	 * mechanism that the old Linux PSB driver uses. Tell them it
 	 * is broken with Windows 2000.
 	 *
 	 * The reference to the AMD documentation is chapter 9 in the
 	 * BIOS and Kernel Developer's Guide, which is available on
 	 * www.amd.com
 	 */
-	printk(KERN_ERR FW_BUG PFX "No PSB or ACPI _PSS objects\n");
+	printk(KERN_ERR PFX "No PSB or ACPI _PSS objects\n");
+	printk(KERN_ERR PFX "Make sure that Cool'N'Quiet support is "
+		"enabled in your BIOS setup\n");
 	return -ENODEV;
 }
 

^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2010-01-20 17:19 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -789,17 +789,20 @@
 	}
 	/*
-	 * If you see this message, complain to BIOS manufacturer. If
-	 * he tells you "we do not support Linux" or some similar
-	 * nonsense, remember that Windows 2000 uses the same legacy
-	 * mechanism that the old Linux PSB driver uses. Tell them it
-	 * is broken with Windows 2000.
+	 * If you see this message, check that Cool'N'Quiet is enabled
+	 * in your BIOS setup. If that fails, complain to your BIOS
+	 * manufacturer. If he tells you "we do not support Linux" or
+	 * some similar nonsense, remember that Windows 2000 uses the
+	 * same legacy mechanism that the old Linux PSB driver uses.
+	 * Tell them it is broken with Windows 2000.
 	 *
 	 * The reference to the AMD documentation is chapter 9 in the
2010-01-20 15:33 [PATCH] powernow-k8: On load failure, remind the user to enable support in BIOS setup Marti Raudsepp
2010-01-20 15:56 ` Thomas Renninger
2010-01-20 17:19   ` Marti Raudsepp

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox